@@ -12,7 +12,7 @@ wrapper: Py3cwClosure = None
 
 @logged
 @with_py3cw
-def get_strategy_list():
+def get_strategy_list(payload: dict = None):
     """
     GET /ver1/bots/strategy_list
     Available strategy list for bot (Permission: BOTS_READ, Security: SIGNED)
@@ -21,13 +21,14 @@ def get_strategy_list():
     error, data = wrapper.request(
         entity='bots',
         action='strategy_list',
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def get_pairs_black_list():
+def get_pairs_black_list(payload: dict = None):
     """
     GET /ver1/bots/pairs_black_list
     Black List for bot pairs (Permission: BOTS_READ, Security: SIGNED)
@@ -36,13 +37,14 @@ def get_pairs_black_list():
     error, data = wrapper.request(
         entity='bots',
         action='pairs_black_list',
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_update_pairs_black_list():
+def post_update_pairs_black_list(payload: dict = None):
     """
     POST /ver1/bots/update_pairs_black_list
     Create or Update pairs BlackList for bots (Permission: BOTS_WRITE, Security: SIGNED)
@@ -51,13 +53,14 @@ def post_update_pairs_black_list():
     error, data = wrapper.request(
         entity='bots',
         action='update_pairs_black_list',
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_create_bot():
+def post_create_bot(payload: dict = None):
     """
     POST /ver1/bots/create_bot
     Create bot (Permission: BOTS_WRITE, Security: SIGNED)
@@ -66,13 +69,14 @@ def post_create_bot():
     error, data = wrapper.request(
         entity='bots',
         action='create_bot',
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def get() -> Tuple[ThreeCommasApiError, List[BotEntity]]:
+def get(payload: dict = None) -> Tuple[ThreeCommasApiError, List[BotEntity]]:
     """
     GET /ver1/bots
     User bots (Permission: BOTS_READ, Security: SIGNED)
@@ -81,13 +85,14 @@ def get() -> Tuple[ThreeCommasApiError, List[BotEntity]]:
     error, data = wrapper.request(
         entity='bots',
         action='',
+        payload=payload,
     )
     return ThreeCommasApiError(error), BotEntity.of_list(data)
 
 
 @logged
 @with_py3cw
-def get_stats():
+def get_stats(payload: dict = None):
     """
     GET /ver1/bots/stats
     Get bot stats (Permission: BOTS_READ, Security: SIGNED)
@@ -96,13 +101,14 @@ def get_stats():
     error, data = wrapper.request(
         entity='bots',
         action='stats',
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_copy_and_create_by_id(bot_id):
+def post_copy_and_create_by_id(id, payload: dict = None):
     """
     POST /ver1/bots/{bot_id}/copy_and_create
     POST /bots/:id/copy_and_create. Permission: BOTS_WRITE, Security: SIGNED
@@ -111,14 +117,15 @@ def post_copy_and_create_by_id(bot_id):
     error, data = wrapper.request(
         entity='bots',
         action='copy_and_create',
-        action_id=str(bot_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def patch_update_by_id(bot_id):
+def patch_update_by_id(id, payload: dict = None):
     """
     PATCH /ver1/bots/{bot_id}/update
     Edit bot (Permission: BOTS_WRITE, Security: SIGNED)
@@ -127,14 +134,15 @@ def patch_update_by_id(bot_id):
     error, data = wrapper.request(
         entity='bots',
         action='update',
-        action_id=str(bot_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_disable_by_id(bot_id):
+def post_disable_by_id(id, payload: dict = None):
     """
     POST /ver1/bots/{bot_id}/disable
     Disable bot (Permission: BOTS_WRITE, Security: SIGNED)
@@ -143,14 +151,15 @@ def post_disable_by_id(bot_id):
     error, data = wrapper.request(
         entity='bots',
         action='disable',
-        action_id=str(bot_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_enable_by_id(bot_id):
+def post_enable_by_id(id, payload: dict = None):
     """
     POST /ver1/bots/{bot_id}/enable
     Enable bot (Permission: BOTS_WRITE, Security: SIGNED)
@@ -159,14 +168,15 @@ def post_enable_by_id(bot_id):
     error, data = wrapper.request(
         entity='bots',
         action='enable',
-        action_id=str(bot_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_start_new_deal_by_id(bot_id):
+def post_start_new_deal_by_id(id, payload: dict = None):
     """
     POST /ver1/bots/{bot_id}/start_new_deal
     Start new deal asap (Permission: BOTS_WRITE, Security: SIGNED)
@@ -175,14 +185,15 @@ def post_start_new_deal_by_id(bot_id):
     error, data = wrapper.request(
         entity='bots',
         action='start_new_deal',
-        action_id=str(bot_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_delete_by_id(bot_id):
+def post_delete_by_id(id, payload: dict = None):
     """
     POST /ver1/bots/{bot_id}/delete
     Delete bot (Permission: BOTS_WRITE, Security: SIGNED)
@@ -191,14 +202,15 @@ def post_delete_by_id(bot_id):
     error, data = wrapper.request(
         entity='bots',
         action='delete',
-        action_id=str(bot_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_panic_sell_all_deals_by_id(bot_id):
+def post_panic_sell_all_deals_by_id(id, payload: dict = None):
     """
     POST /ver1/bots/{bot_id}/panic_sell_all_deals
     Panic sell all bot deals (Permission: BOTS_WRITE, Security: SIGNED)
@@ -207,14 +219,15 @@ def post_panic_sell_all_deals_by_id(bot_id):
     error, data = wrapper.request(
         entity='bots',
         action='panic_sell_all_deals',
-        action_id=str(bot_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_cancel_all_deals_by_id(bot_id):
+def post_cancel_all_deals_by_id(id, payload: dict = None):
     """
     POST /ver1/bots/{bot_id}/cancel_all_deals
     Cancel all bot deals (Permission: BOTS_WRITE, Security: SIGNED)
@@ -223,14 +236,15 @@ def post_cancel_all_deals_by_id(bot_id):
     error, data = wrapper.request(
         entity='bots',
         action='cancel_all_deals',
-        action_id=str(bot_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def get_deals_stats_by_id(bot_id):
+def get_deals_stats_by_id(id, payload: dict = None):
     """
     GET /ver1/bots/{bot_id}/deals_stats
     Bot deals stats (Permission: BOTS_READ, Security: SIGNED)
@@ -239,14 +253,15 @@ def get_deals_stats_by_id(bot_id):
     error, data = wrapper.request(
         entity='bots',
         action='deals_stats',
-        action_id=str(bot_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def get_show_by_id(bot_id) -> Tuple[ThreeCommasApiError, BotEntity]:
+def get_show_by_id(id, payload: dict = None) -> Tuple[ThreeCommasApiError, BotEntity]:
     """
     GET /ver1/bots/{bot_id}/show
     Bot info (Permission: BOTS_READ, Security: SIGNED)
@@ -255,7 +270,8 @@ def get_show_by_id(bot_id) -> Tuple[ThreeCommasApiError, BotEntity]:
     error, data = wrapper.request(
         entity='bots',
         action='show',
-        action_id=str(bot_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), BotEntity(data)
 
